@@ -7,13 +7,15 @@ class GooglePubSubHandler(Handler):
 
     :param google.cloud.pubsub_v1.PublisherClient publisher: pub/sub publisher to use to publish the log records
     :param octue.cloud.pub_sub.topic.Topic topic: topic to publish log records to
+    :param str analysis_id: the UUID of the analysis the instance is handling the log records for
     :param float timeout: timeout in seconds for attempting to publish each log record
     :return None:
     """
 
-    def __init__(self, publisher, topic, timeout=60, *args, **kwargs):
+    def __init__(self, publisher, topic, analysis_id, timeout=60, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.topic = topic
+        self.analysis_id = analysis_id
         self.timeout = timeout
         self._publisher = publisher
 
@@ -30,6 +32,7 @@ class GooglePubSubHandler(Handler):
                     {
                         "type": "log_record",
                         "log_record": vars(record),
+                        "analysis_id": self.analysis_id,
                         "message_number": str(self.topic.messages_published),
                     }
                 ).encode(),
