@@ -1,5 +1,6 @@
 import logging
 import time
+
 import google.api_core.exceptions
 
 
@@ -16,11 +17,11 @@ class Topic:
     :return None:
     """
 
-    def __init__(self, name, namespace, service):
-        if name.startswith(namespace):
-            self.name = name
-        else:
+    def __init__(self, name, service, namespace=""):
+        if namespace and not name.startswith(namespace):
             self.name = f"{namespace}.{name}"
+        else:
+            self.name = name
 
         self.service = service
         self.path = self.generate_topic_path(service.backend.project_name, self.name)
@@ -50,6 +51,13 @@ class Topic:
             pass
         self._log_creation()
 
+    def get_subscriptions(self):
+        """Get the topic's subscriptions' paths.
+
+        :return list(str):
+        """
+        return list(self.service.publisher.list_topic_subscriptions(topic=self.path))
+
     def delete(self):
         """Delete the topic from Google Pub/Sub.
 
